package com.mysql.jdbc;

import com.mysql.jdbc.exceptions.NotYetImplementedException;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/BlobFromLocator.class */
public class BlobFromLocator implements java.sql.Blob {
    private List primaryKeyColumns;
    private List primaryKeyValues;
    private ResultSetImpl creatorResultSet;
    private String blobColumnName;
    private String tableName;
    private int numColsInResultSet;
    private int numPrimaryKeys;
    private String quotedId;

    /* JADX INFO: Access modifiers changed from: package-private */
    public BlobFromLocator(ResultSetImpl creatorResultSetToSet, int blobColumnIndex) throws SQLException {
        this.primaryKeyColumns = null;
        this.primaryKeyValues = null;
        this.blobColumnName = null;
        this.tableName = null;
        this.numColsInResultSet = 0;
        this.numPrimaryKeys = 0;
        this.creatorResultSet = creatorResultSetToSet;
        this.numColsInResultSet = this.creatorResultSet.fields.length;
        this.quotedId = this.creatorResultSet.connection.getMetaData().getIdentifierQuoteString();
        if (this.numColsInResultSet > 1) {
            this.primaryKeyColumns = new ArrayList();
            this.primaryKeyValues = new ArrayList();
            for (int i = 0; i < this.numColsInResultSet; i++) {
                if (this.creatorResultSet.fields[i].isPrimaryKey()) {
                    StringBuffer keyName = new StringBuffer();
                    keyName.append(this.quotedId);
                    String originalColumnName = this.creatorResultSet.fields[i].getOriginalName();
                    if (originalColumnName != null && originalColumnName.length() > 0) {
                        keyName.append(originalColumnName);
                    } else {
                        keyName.append(this.creatorResultSet.fields[i].getName());
                    }
                    keyName.append(this.quotedId);
                    this.primaryKeyColumns.add(keyName.toString());
                    this.primaryKeyValues.add(this.creatorResultSet.getString(i + 1));
                }
            }
        } else {
            notEnoughInformationInQuery();
        }
        this.numPrimaryKeys = this.primaryKeyColumns.size();
        if (this.numPrimaryKeys == 0) {
            notEnoughInformationInQuery();
        }
        if (this.creatorResultSet.fields[0].getOriginalTableName() != null) {
            StringBuffer tableNameBuffer = new StringBuffer();
            String databaseName = this.creatorResultSet.fields[0].getDatabaseName();
            if (databaseName != null && databaseName.length() > 0) {
                tableNameBuffer.append(this.quotedId);
                tableNameBuffer.append(databaseName);
                tableNameBuffer.append(this.quotedId);
                tableNameBuffer.append('.');
            }
            tableNameBuffer.append(this.quotedId);
            tableNameBuffer.append(this.creatorResultSet.fields[0].getOriginalTableName());
            tableNameBuffer.append(this.quotedId);
            this.tableName = tableNameBuffer.toString();
        } else {
            StringBuffer tableNameBuffer2 = new StringBuffer();
            tableNameBuffer2.append(this.quotedId);
            tableNameBuffer2.append(this.creatorResultSet.fields[0].getTableName());
            tableNameBuffer2.append(this.quotedId);
            this.tableName = tableNameBuffer2.toString();
        }
        this.blobColumnName = new StringBuffer().append(this.quotedId).append(this.creatorResultSet.getString(blobColumnIndex)).append(this.quotedId).toString();
    }

    private void notEnoughInformationInQuery() throws SQLException {
        throw SQLError.createSQLException("Emulated BLOB locators must come from a ResultSet with only one table selected, and all primary keys selected", SQLError.SQL_STATE_GENERAL_ERROR);
    }

    @Override // java.sql.Blob
    public OutputStream setBinaryStream(long indexToWriteAt) throws SQLException {
        throw new NotImplemented();
    }

    @Override // java.sql.Blob
    public InputStream getBinaryStream() throws SQLException {
        return new BufferedInputStream(new LocatorInputStream(this), this.creatorResultSet.connection.getLocatorFetchBufferSize());
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:21:0x0152
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.Blob
    public int setBytes(long r7, byte[] r9, int r10, int r11) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 351
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.BlobFromLocator.setBytes(long, byte[], int, int):int");
    }

    @Override // java.sql.Blob
    public int setBytes(long writeAt, byte[] bytes) throws SQLException {
        return setBytes(writeAt, bytes, 0, bytes.length);
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:7:0x0032
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.Blob
    public byte[] getBytes(long r7, int r9) throws java.sql.SQLException {
        /*
            r6 = this;
            r0 = 0
            r10 = r0
            r0 = r6
            java.sql.PreparedStatement r0 = r0.createGetBytesStatement()     // Catch: java.lang.Throwable -> L19
            r10 = r0
            r0 = r6
            r1 = r10
            r2 = r7
            r3 = r9
            byte[] r0 = r0.getBytesInternal(r1, r2, r3)     // Catch: java.lang.Throwable -> L19
            r11 = r0
            r0 = jsr -> L21
        L16:
            r1 = r11
            return r1
        L19:
            r12 = move-exception
            r0 = jsr -> L21
        L1e:
            r1 = r12
            throw r1
        L21:
            r13 = r0
            r0 = r10
            if (r0 == 0) goto L37
            r0 = r10
            r0.close()     // Catch: java.sql.SQLException -> L32
            goto L34
        L32:
            r14 = move-exception
        L34:
            r0 = 0
            r10 = r0
        L37:
            ret r13
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.BlobFromLocator.getBytes(long, int):byte[]");
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:20:0x0102
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.Blob
    public long length() throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 264
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.BlobFromLocator.length():long");
    }

    @Override // java.sql.Blob
    public long position(java.sql.Blob pattern, long start) throws SQLException {
        return position(pattern.getBytes(0L, (int) pattern.length()), start);
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:20:0x013a
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.Blob
    public long position(byte[] r6, long r7) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 321
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.BlobFromLocator.position(byte[], long):long");
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:18:0x0110
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    @Override // java.sql.Blob
    public void truncate(long r6) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 279
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.BlobFromLocator.truncate(long):void");
    }

    java.sql.PreparedStatement createGetBytesStatement() throws SQLException {
        StringBuffer query = new StringBuffer("SELECT SUBSTRING(");
        query.append(this.blobColumnName);
        query.append(", ");
        query.append("?");
        query.append(", ");
        query.append("?");
        query.append(") FROM ");
        query.append(this.tableName);
        query.append(" WHERE ");
        query.append((String) this.primaryKeyColumns.get(0));
        query.append(" = ?");
        for (int i = 1; i < this.numPrimaryKeys; i++) {
            query.append(" AND ");
            query.append((String) this.primaryKeyColumns.get(i));
            query.append(" = ?");
        }
        return this.creatorResultSet.connection.prepareStatement(query.toString());
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:13:0x0083
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    byte[] getBytesInternal(java.sql.PreparedStatement r6, long r7, int r9) throws java.sql.SQLException {
        /*
            r5 = this;
            r0 = 0
            r10 = r0
            r0 = r6
            r1 = 1
            r2 = r7
            r0.setLong(r1, r2)     // Catch: java.lang.Throwable -> L6a
            r0 = r6
            r1 = 2
            r2 = r9
            r0.setInt(r1, r2)     // Catch: java.lang.Throwable -> L6a
            r0 = 0
            r11 = r0
        L17:
            r0 = r11
            r1 = r5
            int r1 = r1.numPrimaryKeys     // Catch: java.lang.Throwable -> L6a
            if (r0 >= r1) goto L3e
            r0 = r6
            r1 = r11
            r2 = 3
            int r1 = r1 + r2
            r2 = r5
            java.util.List r2 = r2.primaryKeyValues     // Catch: java.lang.Throwable -> L6a
            r3 = r11
            java.lang.Object r2 = r2.get(r3)     // Catch: java.lang.Throwable -> L6a
            java.lang.String r2 = (java.lang.String) r2     // Catch: java.lang.Throwable -> L6a
            r0.setString(r1, r2)     // Catch: java.lang.Throwable -> L6a
            int r11 = r11 + 1
            goto L17
        L3e:
            r0 = r6
            java.sql.ResultSet r0 = r0.executeQuery()     // Catch: java.lang.Throwable -> L6a
            r10 = r0
            r0 = r10
            boolean r0 = r0.next()     // Catch: java.lang.Throwable -> L6a
            if (r0 == 0) goto L62
            r0 = r10
            com.mysql.jdbc.ResultSetImpl r0 = (com.mysql.jdbc.ResultSetImpl) r0     // Catch: java.lang.Throwable -> L6a
            r1 = 1
            r2 = 1
            byte[] r0 = r0.getBytes(r1, r2)     // Catch: java.lang.Throwable -> L6a
            r11 = r0
            r0 = jsr -> L72
        L5f:
            r1 = r11
            return r1
        L62:
            java.lang.String r0 = "BLOB data not found! Did primary keys change?"
            java.lang.String r1 = "S1000"
            java.sql.SQLException r0 = com.mysql.jdbc.SQLError.createSQLException(r0, r1)     // Catch: java.lang.Throwable -> L6a
            throw r0     // Catch: java.lang.Throwable -> L6a
        L6a:
            r12 = move-exception
            r0 = jsr -> L72
        L6f:
            r1 = r12
            throw r1
        L72:
            r13 = r0
            r0 = r10
            if (r0 == 0) goto L88
            r0 = r10
            r0.close()     // Catch: java.sql.SQLException -> L83
            goto L85
        L83:
            r14 = move-exception
        L85:
            r0 = 0
            r10 = r0
        L88:
            ret r13
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.BlobFromLocator.getBytesInternal(java.sql.PreparedStatement, long, int):byte[]");
    }

    /* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/BlobFromLocator$LocatorInputStream.class */
    class LocatorInputStream extends InputStream {
        long currentPositionInBlob = 0;
        long length;
        java.sql.PreparedStatement pStmt;
        private final BlobFromLocator this$0;

        LocatorInputStream(BlobFromLocator this$0) throws SQLException {
            this.this$0 = this$0;
            this.length = 0L;
            this.pStmt = null;
            this.length = this$0.length();
            this.pStmt = this$0.createGetBytesStatement();
        }

        @Override // java.io.InputStream
        public int read() throws IOException {
            if (this.currentPositionInBlob + 1 > this.length) {
                return -1;
            }
            try {
                BlobFromLocator blobFromLocator = this.this$0;
                java.sql.PreparedStatement preparedStatement = this.pStmt;
                long j = this.currentPositionInBlob;
                this.currentPositionInBlob = j + 1;
                byte[] asBytes = blobFromLocator.getBytesInternal(preparedStatement, j + 1, 1);
                if (asBytes == null) {
                    return -1;
                }
                return asBytes[0];
            } catch (SQLException sqlEx) {
                throw new IOException(sqlEx.toString());
            }
        }

        @Override // java.io.InputStream
        public int read(byte[] b, int off, int len) throws IOException {
            if (this.currentPositionInBlob + 1 > this.length) {
                return -1;
            }
            try {
                byte[] asBytes = this.this$0.getBytesInternal(this.pStmt, this.currentPositionInBlob + 1, len);
                if (asBytes == null) {
                    return -1;
                }
                System.arraycopy(asBytes, 0, b, off, asBytes.length);
                this.currentPositionInBlob += asBytes.length;
                return asBytes.length;
            } catch (SQLException sqlEx) {
                throw new IOException(sqlEx.toString());
            }
        }

        @Override // java.io.InputStream
        public int read(byte[] b) throws IOException {
            if (this.currentPositionInBlob + 1 > this.length) {
                return -1;
            }
            try {
                byte[] asBytes = this.this$0.getBytesInternal(this.pStmt, this.currentPositionInBlob + 1, b.length);
                if (asBytes == null) {
                    return -1;
                }
                System.arraycopy(asBytes, 0, b, 0, asBytes.length);
                this.currentPositionInBlob += asBytes.length;
                return asBytes.length;
            } catch (SQLException sqlEx) {
                throw new IOException(sqlEx.toString());
            }
        }

        @Override // java.io.InputStream, java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
            if (this.pStmt != null) {
                try {
                    this.pStmt.close();
                } catch (SQLException sqlEx) {
                    throw new IOException(sqlEx.toString());
                }
            }
            super.close();
        }
    }

    @Override // java.sql.Blob
    public void free() throws SQLException {
        this.creatorResultSet = null;
        this.primaryKeyColumns = null;
        this.primaryKeyValues = null;
    }

    @Override // java.sql.Blob
    public InputStream getBinaryStream(long pos, long length) throws SQLException {
        throw new NotYetImplementedException();
    }
}
